# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: powerpay_protos/measurement.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'powerpay_protos/measurement.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!powerpay_protos/measurement.proto\x12\x14powerpay.measurement\x1a\x1fgoogle/protobuf/timestamp.proto\"\xcb\x02\n\x0bMeasurement\x12.\n\x06\x65nergy\x18\x01 \x01(\x0b\x32\x1c.powerpay.measurement.EnergyH\x00\x12,\n\x05power\x18\x02 \x01(\x0b\x32\x1b.powerpay.measurement.PowerH\x00\x12,\n\x05state\x18\x03 \x01(\x0b\x32\x1b.powerpay.measurement.StateH\x00\x12\x30\n\x07session\x18\x04 \x01(\x0b\x32\x1d.powerpay.measurement.SessionH\x00\x12?\n\x0fsignal_strength\x18\x05 \x01(\x0b\x32$.powerpay.measurement.SignalStrengthH\x00\x12\x35\n\nrfid_event\x18\x06 \x01(\x0b\x32\x1f.powerpay.measurement.RFIDEventH\x00\x42\x06\n\x04type\"\xcc\x01\n\x06\x45nergy\x12\r\n\x05value\x18\x01 \x01(\x03\x12.\n\x04unit\x18\x02 \x01(\x0e\x32 .powerpay.measurement.EnergyUnit\x12\x35\n\x04type\x18\x03 \x01(\x0e\x32\'.powerpay.measurement.Energy.EnergyType\"L\n\nEnergyType\x12#\n\x1f\x45NERGY_MEASUREMENT_TYPE_NOT_SET\x10\x00\x12\x0c\n\x08LIFETIME\x10\x01\x12\x0b\n\x07SESSION\x10\x02\"E\n\x05Power\x12\r\n\x05value\x18\x01 \x01(\x01\x12-\n\x04unit\x18\x02 \x01(\x0e\x32\x1f.powerpay.measurement.PowerUnit\"\xd8\x03\n\x05State\x12=\n\tenergized\x18\x01 \x01(\x0e\x32*.powerpay.measurement.State.EnergizedState\x12\x37\n\x06online\x18\x02 \x01(\x0e\x32\'.powerpay.measurement.State.OnlineState\x12=\n\tconnected\x18\x03 \x01(\x0e\x32*.powerpay.measurement.State.ConnectedState\x12\x30\n\x06inputs\x18\x04 \x01(\x0b\x32 .powerpay.measurement.InputState\"P\n\x0e\x45nergizedState\x12\x1d\n\x19\x45NERGIZED_STATE_UNDEFINED\x10\x00\x12\r\n\tENERGIZED\x10\x01\x12\x10\n\x0c\x44\x45_ENERGIZED\x10\x02\"B\n\x0bOnlineState\x12\x1a\n\x16ONLINE_STATE_UNDEFINED\x10\x00\x12\n\n\x06ONLINE\x10\x01\x12\x0b\n\x07OFFLINE\x10\x02\"P\n\x0e\x43onnectedState\x12\x1d\n\x19\x43ONNECTED_STATE_UNDEFINED\x10\x00\x12\r\n\tCONNECTED\x10\x01\x12\x10\n\x0c\x44ISCONNECTED\x10\x02\"N\n\nInputState\x12$\n\x17\x63ircuit_breaker_tripped\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x1a\n\x18_circuit_breaker_tripped\"\x80\x02\n\x07Session\x12)\n\x05start\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12=\n\x17session_consumed_energy\x18\x03 \x01(\x0b\x32\x1c.powerpay.measurement.Energy\x12\x31\n\x0bmeter_start\x18\x04 \x01(\x0b\x32\x1c.powerpay.measurement.Energy\x12/\n\tmeter_end\x18\x05 \x01(\x0b\x32\x1c.powerpay.measurement.Energy\"\x8c\x03\n\x0eSignalStrength\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x45\n\x04unit\x18\x02 \x01(\x0e\x32\x37.powerpay.measurement.SignalStrength.SignalStrengthUnit\x12\x42\n\nradio_type\x18\x03 \x01(\x0e\x32..powerpay.measurement.SignalStrength.RadioType\"\x8d\x01\n\x12SignalStrengthUnit\x12 \n\x1cSIGNAL_STRENGTH_UNIT_NOT_SET\x10\x00\x12\x15\n\x11\x44\x45\x43IBEL_MILLIWATT\x10\x01\x12&\n\"RECEIVED_SIGNAL_STRENGTH_INDICATOR\x10\x02\x12\x16\n\x12SIGNAL_NOISE_RATIO\x10\x03\"P\n\tRadioType\x12\x16\n\x12RADIO_TYPE_NOT_SET\x10\x00\x12\x0c\n\x08\x43\x45LLULAR\x10\x01\x12\x08\n\x04WIFI\x10\x02\x12\x08\n\x04LORA\x10\x03\x12\t\n\x05LOCAL\x10\x04\"\x18\n\tRFIDEvent\x12\x0b\n\x03uid\x18\x01 \x01(\x0c*\\\n\nEnergyUnit\x12\x17\n\x13\x45NERGY_UNIT_NOT_SET\x10\x00\x12\r\n\tWATT_HOUR\x10\x01\x12\x12\n\x0eKILO_WATT_HOUR\x10\x02\x12\x12\n\x0eMEGA_WATT_HOUR\x10\x03*K\n\tPowerUnit\x12\x16\n\x12POWER_UNIT_NOT_SET\x10\x00\x12\x08\n\x04WATT\x10\x01\x12\r\n\tKILO_WATT\x10\x02\x12\r\n\tMEGA_WATT\x10\x03\x42\x06Z\x04./pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'powerpay_protos.measurement_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\004./pb'
  _globals['_ENERGYUNIT']._serialized_start=1943
  _globals['_ENERGYUNIT']._serialized_end=2035
  _globals['_POWERUNIT']._serialized_start=2037
  _globals['_POWERUNIT']._serialized_end=2112
  _globals['_MEASUREMENT']._serialized_start=93
  _globals['_MEASUREMENT']._serialized_end=424
  _globals['_ENERGY']._serialized_start=427
  _globals['_ENERGY']._serialized_end=631
  _globals['_ENERGY_ENERGYTYPE']._serialized_start=555
  _globals['_ENERGY_ENERGYTYPE']._serialized_end=631
  _globals['_POWER']._serialized_start=633
  _globals['_POWER']._serialized_end=702
  _globals['_STATE']._serialized_start=705
  _globals['_STATE']._serialized_end=1177
  _globals['_STATE_ENERGIZEDSTATE']._serialized_start=947
  _globals['_STATE_ENERGIZEDSTATE']._serialized_end=1027
  _globals['_STATE_ONLINESTATE']._serialized_start=1029
  _globals['_STATE_ONLINESTATE']._serialized_end=1095
  _globals['_STATE_CONNECTEDSTATE']._serialized_start=1097
  _globals['_STATE_CONNECTEDSTATE']._serialized_end=1177
  _globals['_INPUTSTATE']._serialized_start=1179
  _globals['_INPUTSTATE']._serialized_end=1257
  _globals['_SESSION']._serialized_start=1260
  _globals['_SESSION']._serialized_end=1516
  _globals['_SIGNALSTRENGTH']._serialized_start=1519
  _globals['_SIGNALSTRENGTH']._serialized_end=1915
  _globals['_SIGNALSTRENGTH_SIGNALSTRENGTHUNIT']._serialized_start=1692
  _globals['_SIGNALSTRENGTH_SIGNALSTRENGTHUNIT']._serialized_end=1833
  _globals['_SIGNALSTRENGTH_RADIOTYPE']._serialized_start=1835
  _globals['_SIGNALSTRENGTH_RADIOTYPE']._serialized_end=1915
  _globals['_RFIDEVENT']._serialized_start=1917
  _globals['_RFIDEVENT']._serialized_end=1941
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: powerpay_protos/integration.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'powerpay_protos/integration.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!powerpay_protos/integration.proto\x12\x14powerpay.integration\x1a\x1cgoogle/protobuf/struct.proto\"]\n\x1aIntegrationTemplateRequest\x12?\n\x10integration_type\x18\x01 \x01(\x0e\x32%.powerpay.integration.IntegrationType\"\xc2\x01\n\x13IntegrationTemplate\x12\x38\n\x12integration_config\x18\x01 \x01(\x0b\x32\x1c.powerpay.integration.Schema\x12<\n\x16integration_properties\x18\x02 \x01(\x0b\x32\x1c.powerpay.integration.Schema\x12\x33\n\rdevice_config\x18\x03 \x01(\x0b\x32\x1c.powerpay.integration.Schema\"b\n\x06Schema\x12*\n\tui_schema\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bjson_schema\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"6\n\x13HealthCheckResponse\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\"\xd6\x01\n\x0bIntegration\x12?\n\x10integration_type\x18\x01 \x01(\x0e\x32%.powerpay.integration.IntegrationType\x12\x18\n\x10integration_name\x18\x02 \x01(\t\x12\x33\n\x12integration_config\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x37\n\x16integration_properties\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct*\x9a\x01\n\x0fIntegrationType\x12\x1e\n\x1aINTEGRATION_TYPE_UNDEFINED\x10\x00\x12\x0e\n\nCHIRPSTACK\x10\x01\x12\t\n\x05\x45\x41SEE\x10\x02\x12\x0b\n\x07NETMORE\x10\x03\x12\x08\n\x04OCPP\x10\x04\x12\x08\n\x04MQTT\x10\x05\x12\r\n\tTHINGPARK\x10\x06\x12\n\n\x06RESIOT\x10\x07\x12\x10\n\x0c\x43HIRPSTACKV4\x10\x08\x32\xec\x01\n\x12IntegrationService\x12]\n\x0bHealthCheck\x12!.powerpay.integration.Integration\x1a).powerpay.integration.HealthCheckResponse\"\x00\x12w\n\x16GetIntegrationTemplate\x12\x30.powerpay.integration.IntegrationTemplateRequest\x1a).powerpay.integration.IntegrationTemplate\"\x00\x42\x06Z\x04./pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'powerpay_protos.integration_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\004./pb'
  _globals['_INTEGRATIONTYPE']._serialized_start=755
  _globals['_INTEGRATIONTYPE']._serialized_end=909
  _globals['_INTEGRATIONTEMPLATEREQUEST']._serialized_start=89
  _globals['_INTEGRATIONTEMPLATEREQUEST']._serialized_end=182
  _globals['_INTEGRATIONTEMPLATE']._serialized_start=185
  _globals['_INTEGRATIONTEMPLATE']._serialized_end=379
  _globals['_SCHEMA']._serialized_start=381
  _globals['_SCHEMA']._serialized_end=479
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=481
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=535
  _globals['_INTEGRATION']._serialized_start=538
  _globals['_INTEGRATION']._serialized_end=752
  _globals['_INTEGRATIONSERVICE']._serialized_start=912
  _globals['_INTEGRATIONSERVICE']._serialized_end=1148
# @@protoc_insertion_point(module_scope)



from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class IntegrationType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    INTEGRATION_TYPE_UNDEFINED: _ClassVar[IntegrationType]
    CHIRPSTACK: _ClassVar[IntegrationType]
    EASEE: _ClassVar[IntegrationType]
    NETMORE: _ClassVar[IntegrationType]
    OCPP: _ClassVar[IntegrationType]
    MQTT: _ClassVar[IntegrationType]
    THINGPARK: _ClassVar[IntegrationType]
    RESIOT: _ClassVar[IntegrationType]
    CHIRPSTACKV4: _ClassVar[IntegrationType]
INTEGRATION_TYPE_UNDEFINED: IntegrationType
CHIRPSTACK: IntegrationType
EASEE: IntegrationType
NETMORE: IntegrationType
OCPP: IntegrationType
MQTT: IntegrationType
THINGPARK: IntegrationType
RESIOT: IntegrationType
CHIRPSTACKV4: IntegrationType

class IntegrationTemplateRequest(_message.Message):
    __slots__ = ("integration_type",)
    INTEGRATION_TYPE_FIELD_NUMBER: _ClassVar[int]
    integration_type: IntegrationType
    def __init__(self, integration_type: _Optional[_Union[IntegrationType, str]] = ...) -> None: ...

class IntegrationTemplate(_message.Message):
    __slots__ = ("integration_config", "integration_properties", "device_config")
    INTEGRATION_CONFIG_FIELD_NUMBER: _ClassVar[int]
    INTEGRATION_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    DEVICE_CONFIG_FIELD_NUMBER: _ClassVar[int]
    integration_config: Schema
    integration_properties: Schema
    device_config: Schema
    def __init__(self, integration_config: _Optional[_Union[Schema, _Mapping]] = ..., integration_properties: _Optional[_Union[Schema, _Mapping]] = ..., device_config: _Optional[_Union[Schema, _Mapping]] = ...) -> None: ...

class Schema(_message.Message):
    __slots__ = ("ui_schema", "json_schema")
    UI_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    JSON_SCHEMA_FIELD_NUMBER: _ClassVar[int]
    ui_schema: _struct_pb2.Struct
    json_schema: _struct_pb2.Struct
    def __init__(self, ui_schema: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., json_schema: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class HealthCheckResponse(_message.Message):
    __slots__ = ("status", "message")
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    status: bool
    message: str
    def __init__(self, status: bool = ..., message: _Optional[str] = ...) -> None: ...

class Integration(_message.Message):
    __slots__ = ("integration_type", "integration_name", "integration_config", "integration_properties")
    INTEGRATION_TYPE_FIELD_NUMBER: _ClassVar[int]
    INTEGRATION_NAME_FIELD_NUMBER: _ClassVar[int]
    INTEGRATION_CONFIG_FIELD_NUMBER: _ClassVar[int]
    INTEGRATION_PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    integration_type: IntegrationType
    integration_name: str
    integration_config: _struct_pb2.Struct
    integration_properties: _struct_pb2.Struct
    def __init__(self, integration_type: _Optional[_Union[IntegrationType, str]] = ..., integration_name: _Optional[str] = ..., integration_config: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., integration_properties: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: powerpay_protos/telemetry.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'powerpay_protos/telemetry.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from powerpay_protos import measurement_pb2 as powerpay__protos_dot_measurement__pb2
from powerpay_protos import device_pb2 as powerpay__protos_dot_device__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fpowerpay_protos/telemetry.proto\x12\x12powerpay.telemetry\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!powerpay_protos/measurement.proto\x1a\x1cpowerpay_protos/device.proto\"\x9b\x01\n\tTelemetry\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\x06\x64\x65vice\x18\x02 \x01(\x0b\x32\x17.powerpay.device.Device\x12\x36\n\x0bmeasurement\x18\x03 \x03(\x0b\x32!.powerpay.measurement.MeasurementB\x06Z\x04./pbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'powerpay_protos.telemetry_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\004./pb'
  _globals['_TELEMETRY']._serialized_start=154
  _globals['_TELEMETRY']._serialized_end=309
# @@protoc_insertion_point(module_scope)



import datetime

from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from powerpay_protos import integration_pb2 as _integration_pb2
from powerpay_protos import measurement_pb2 as _measurement_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class OperationStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    OPERATION_STATUS_UNDEFINED: _ClassVar[OperationStatus]
    SUCCESS: _ClassVar[OperationStatus]
    FAILURE: _ClassVar[OperationStatus]
    TIMEOUT: _ClassVar[OperationStatus]
    NOT_FOUND: _ClassVar[OperationStatus]
    NOT_SUPPORTED: _ClassVar[OperationStatus]
    INVALID: _ClassVar[OperationStatus]

class DeviceControlType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DEVICE_CONTROL_UNDEFINED: _ClassVar[DeviceControlType]
    ENERGIZE: _ClassVar[DeviceControlType]
    DE_ENERGIZE: _ClassVar[DeviceControlType]
    RESTART: _ClassVar[DeviceControlType]
    READ_SERIAL_NUMBER: _ClassVar[DeviceControlType]
OPERATION_STATUS_UNDEFINED: OperationStatus
SUCCESS: OperationStatus
FAILURE: OperationStatus
TIMEOUT: OperationStatus
NOT_FOUND: OperationStatus
NOT_SUPPORTED: OperationStatus
INVALID: OperationStatus
DEVICE_CONTROL_UNDEFINED: DeviceControlType
ENERGIZE: DeviceControlType
DE_ENERGIZE: DeviceControlType
RESTART: DeviceControlType
READ_SERIAL_NUMBER: DeviceControlType

class Device(_message.Message):
    __slots__ = ("native_id", "integration_type", "outlet_index", "integration_name")
    NATIVE_ID_FIELD_NUMBER: _ClassVar[int]
    INTEGRATION_TYPE_FIELD_NUMBER: _ClassVar[int]
    OUTLET_INDEX_FIELD_NUMBER: _ClassVar[int]
    INTEGRATION_NAME_FIELD_NUMBER: _ClassVar[int]
    native_id: str
    integration_type: _integration_pb2.IntegrationType
    outlet_index: int
    integration_name: str
    def __init__(self, native_id: _Optional[str] = ..., integration_type: _Optional[_Union[_integration_pb2.IntegrationType, str]] = ..., outlet_index: _Optional[int] = ..., integration_name: _Optional[str] = ...) -> None: ...

class DeviceRequest(_message.Message):
    __slots__ = ("integration", "native_id", "outlet_index", "config", "properties")
    INTEGRATION_FIELD_NUMBER: _ClassVar[int]
    NATIVE_ID_FIELD_NUMBER: _ClassVar[int]
    OUTLET_INDEX_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    integration: _integration_pb2.Integration
    native_id: str
    outlet_index: int
    config: _struct_pb2.Struct
    properties: _struct_pb2.Struct
    def __init__(self, integration: _Optional[_Union[_integration_pb2.Integration, _Mapping]] = ..., native_id: _Optional[str] = ..., outlet_index: _Optional[int] = ..., config: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., properties: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class DeviceResponse(_message.Message):
    __slots__ = ("device", "status", "message")
    DEVICE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    device: Device
    status: OperationStatus
    message: str
    def __init__(self, device: _Optional[_Union[Device, _Mapping]] = ..., status: _Optional[_Union[OperationStatus, str]] = ..., message: _Optional[str] = ...) -> None: ...

class DeviceControlCommand(_message.Message):
    __slots__ = ("type", "properties")
    TYPE_FIELD_NUMBER: _ClassVar[int]
    PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    type: DeviceControlType
    properties: _struct_pb2.Struct
    def __init__(self, type: _Optional[_Union[DeviceControlType, str]] = ..., properties: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...) -> None: ...

class DeviceControlRequest(_message.Message):
    __slots__ = ("device", "command")
    DEVICE_FIELD_NUMBER: _ClassVar[int]
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    device: DeviceRequest
    command: DeviceControlCommand
    def __init__(self, device: _Optional[_Union[DeviceRequest, _Mapping]] = ..., command: _Optional[_Union[DeviceControlCommand, _Mapping]] = ...) -> None: ...

class CreateDeviceRequest(_message.Message):
    __slots__ = ("device", "outlet_count")
    DEVICE_FIELD_NUMBER: _ClassVar[int]
    OUTLET_COUNT_FIELD_NUMBER: _ClassVar[int]
    device: DeviceRequest
    outlet_count: int
    def __init__(self, device: _Optional[_Union[DeviceRequest, _Mapping]] = ..., outlet_count: _Optional[int] = ...) -> None: ...

class UpdateDeviceRequest(_message.Message):
    __slots__ = ("device",)
    DEVICE_FIELD_NUMBER: _ClassVar[int]
    device: DeviceRequest
    def __init__(self, device: _Optional[_Union[DeviceRequest, _Mapping]] = ...) -> None: ...

class DeleteDeviceRequest(_message.Message):
    __slots__ = ("device",)
    DEVICE_FIELD_NUMBER: _ClassVar[int]
    device: DeviceRequest
    def __init__(self, device: _Optional[_Union[DeviceRequest, _Mapping]] = ...) -> None: ...

class DeviceStatusRequest(_message.Message):
    __slots__ = ("device",)
    DEVICE_FIELD_NUMBER: _ClassVar[int]
    device: DeviceRequest
    def __init__(self, device: _Optional[_Union[DeviceRequest, _Mapping]] = ...) -> None: ...

class DeviceStatusResponse(_message.Message):
    __slots__ = ("device", "state", "last_seen")
    DEVICE_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    LAST_SEEN_FIELD_NUMBER: _ClassVar[int]
    device: Device
    state: _measurement_pb2.State
    last_seen: _timestamp_pb2.Timestamp
    def __init__(self, device: _Optional[_Union[Device, _Mapping]] = ..., state: _Optional[_Union[_measurement_pb2.State, _Mapping]] = ..., last_seen: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
